==> webkit2gtk_2.34.1.orig.tar.xz: webkitgtk-2.34.1/Source/WebKit/UIProcess/WebAuthentication/fido/FidoAuthenticator.cpp <==
/*
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "FidoAuthenticator.h"

#if ENABLE(WEB_AUTHN)

#include "CtapDriver.h"

namespace WebKit {

FidoAuthenticator::FidoAuthenticator(std::unique_ptr<CtapDriver>&& driver)
    : m_driver(WTFMove(driver))
{
    ASSERT(m_driver);
}

FidoAuthenticator::~FidoAuthenticator()
{
    if (m_driver)
        m_driver->cancel();
}

CtapDriver& FidoAuthenticator::driver() const
{
    ASSERT(m_driver);
    return *m_driver;
}

std::unique_ptr<CtapDriver> FidoAuthenticator::releaseDriver()
{
    ASSERT(m_driver);
    return WTFMove(m_driver);
}

} // namespace WebKit

#endif // ENABLE(WEB_AUTHN)

==> webkit2gtk_2.48.7.orig.tar.xz: webkitgtk-2.48.7/Source/WebKit/UIProcess/WebAuthentication/fido/FidoAuthenticator.cpp <==
/*
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "FidoAuthenticator.h"
#include <WebCore/WebAuthenticationUtils.h>

#if ENABLE(WEB_AUTHN)

#include "CtapDriver.h"

namespace WebKit {

FidoAuthenticator::FidoAuthenticator(Ref<CtapDriver>&& driver)
    : m_driver(WTFMove(driver))
{
    ASSERT(m_driver);
}

FidoAuthenticator::~FidoAuthenticator()
{
    if (RefPtr driver = m_driver)
        driver->cancel();
}

CtapDriver& FidoAuthenticator::driver() const
{
    ASSERT(m_driver);
    return *m_driver;
}

Ref<CtapDriver> FidoAuthenticator::releaseDriver()
{
    ASSERT(m_driver);
    return m_driver.releaseNonNull();
}

String FidoAuthenticator::transportForDebugging() const
{
    return WebCore::toString(driver().transport());
}

} // namespace WebKit

#endif // ENABLE(WEB_AUTHN)
